instrumenttools.Flute
=====================

.. abjad-lineage:: abjad.tools.instrumenttools.Flute.Flute.Flute

.. autoclass:: abjad.tools.instrumenttools.Flute.Flute.Flute
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.instrumenttools.Flute.Flute.Flute.default_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Flute.Flute.Flute.default_short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Flute.Flute.Flute.effective_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Flute.Flute.Flute.interval_of_transposition
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Flute.Flute.Flute.is_primary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Flute.Flute.Flute.is_secondary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Flute.Flute.Flute.is_transposing
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Flute.Flute.Flute.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Flute.Flute.Flute.start_component
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Flute.Flute.Flute.storage_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Flute.Flute.Flute.target_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Flute.Flute.Flute.traditional_pitch_range
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.instrumenttools.Flute.Flute.Flute.all_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Flute.Flute.Flute.instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Flute.Flute.Flute.instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Flute.Flute.Flute.pitch_range
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Flute.Flute.Flute.primary_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Flute.Flute.Flute.short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Flute.Flute.Flute.short_instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Flute.Flute.Flute.sounding_pitch_of_fingered_middle_c
   :noindex:

Methods
-------

.. automethod:: abjad.tools.instrumenttools.Flute.Flute.Flute.attach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Flute.Flute.Flute.detach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Flute.Flute.Flute.get_default_performer_name
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Flute.Flute.Flute.get_performer_names
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.instrumenttools.Flute.Flute.Flute.__call__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Flute.Flute.Flute.__delattr__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Flute.Flute.Flute.__eq__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Flute.Flute.Flute.__ge__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Flute.Flute.Flute.__gt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Flute.Flute.Flute.__hash__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Flute.Flute.Flute.__le__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Flute.Flute.Flute.__lt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Flute.Flute.Flute.__ne__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Flute.Flute.Flute.__repr__
   :noindex:
